==> otyacraftengine-fabric-3.1.1-pre.3-sources.jar: dev/felnull/otyacraftengine/fabric/data/provider/WrappedFabricItemModelProvider.java <==
package dev.felnull.otyacraftengine.fabric.data.provider;

import dev.felnull.otyacraftengine.data.provider.ItemModelProviderWrapper;
import net.fabricmc.fabric.api.datagen.v1.FabricDataGenerator;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricModelProvider;
import net.minecraft.class_1792;
import net.minecraft.class_4910;
import net.minecraft.class_4915;
import net.minecraft.class_4943;

public class WrappedFabricItemModelProvider extends FabricModelProvider {
    private final ItemModelProviderWrapper itemModelProviderWrapper;

    public WrappedFabricItemModelProvider(FabricDataGenerator dataGenerator, ItemModelProviderWrapper itemModelProviderWrapper) {
        super(dataGenerator);
        this.itemModelProviderWrapper = itemModelProviderWrapper;
    }

    @Override
    public void generateBlockStateModels(class_4910 blockStateModelGenerator) {
    }

    @Override
    public void generateItemModels(class_4915 itemModelGenerator) {
        this.itemModelProviderWrapper.generateItemModels(new ItemModelProviderAccessImpl(itemModelGenerator));
    }

    private static class ItemModelProviderAccessImpl implements ItemModelProviderWrapper.ItemModelProviderAccess {
        private final class_4915 itemModelGenerators;

        private ItemModelProviderAccessImpl(class_4915 itemModelGenerator) {
            this.itemModelGenerators = itemModelGenerator;
        }

        @Override
        public void basicFlatItem(class_1792 item) {
            this.itemModelGenerators.method_25733(item, class_4943.field_22938);
        }
    }
}

==> otyacraftengine-fabric-3.2.0-pre.13-sources.jar: dev/felnull/otyacraftengine/fabric/data/provider/WrappedFabricItemModelProvider.java <==
package dev.felnull.otyacraftengine.fabric.data.provider;

import dev.felnull.otyacraftengine.data.provider.ItemModelProviderWrapper;
import dev.felnull.otyacraftengine.fabric.mixin.data.ItemModelGeneratorsAccessor;
import net.fabricmc.fabric.api.datagen.v1.FabricDataGenerator;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricModelProvider;
import net.minecraft.class_1792;
import net.minecraft.class_2960;
import net.minecraft.class_4910;
import net.minecraft.class_4915;
import net.minecraft.class_4941;
import net.minecraft.class_4942;
import net.minecraft.class_4943;
import net.minecraft.class_4944;
import java.util.Optional;

public class WrappedFabricItemModelProvider extends FabricModelProvider {
    public static final class_4942 BUILTIN_ENTITY = new class_4942(Optional.of(new class_2960("minecraft", "builtin/entity")), Optional.empty());
    private final ItemModelProviderWrapper itemModelProviderWrapper;

    public WrappedFabricItemModelProvider(FabricDataGenerator dataGenerator, ItemModelProviderWrapper itemModelProviderWrapper) {
        super(dataGenerator);
        this.itemModelProviderWrapper = itemModelProviderWrapper;
    }

    @Override
    public void generateBlockStateModels(class_4910 blockStateModelGenerator) {
    }

    @Override
    public void generateItemModels(class_4915 itemModelGenerator) {
        this.itemModelProviderWrapper.generateItemModels(new ItemModelProviderAccessImpl(itemModelGenerator));
    }

    private static class ItemModelProviderAccessImpl implements ItemModelProviderWrapper.ItemModelProviderAccess {
        private final class_4915 itemModelGenerators;

        private ItemModelProviderAccessImpl(class_4915 itemModelGenerator) {
            this.itemModelGenerators = itemModelGenerator;
        }

        @Override
        public void basicFlatItem(class_1792 item) {
            this.itemModelGenerators.method_25733(item, class_4943.field_22938);
        }

        @Override
        public void builtinEntity(class_1792 item) {
            var access = (ItemModelGeneratorsAccessor) itemModelGenerators;
            BUILTIN_ENTITY.method_25852(class_4941.method_25840(item), new class_4944(), access.getOutput());
        }
    }
}
